{% load static %}

<h3 class="myuw-card-title">Husky Experience Toolkit</h3>
<p class="myuw-card-tagline">Make the most of each week</p>

<div class="myuw-article-teaser-wrapper">
    
        <img class="myuw-card-image-full"
             srcset="{% static 'hx_toolkit_output/images/first_impressions_matter_480.jpg' %} 480w,
                 {% static 'hx_toolkit_output/images/first_impressions_matter_650.jpg' %} 650w,
                 {% static 'hx_toolkit_output/images/first_impressions_matter_780.jpg' %} 780w,
                 {% static 'hx_toolkit_output/images/first_impressions_matter_1000.jpg' %} 1000w"
             sizes="(max-width: 767px) 480vw,
                650px"
             src="{% static 'hx_toolkit_output/images/first_impressions_matter_650.jpg' %}"
             alt="A student composing an email on his laptop in Paccar Hall.">
    

    <div class="myuw-article-teaser">
        <h4 class="myuw-article-teaser-title"><span class="myuw-highlight"><a href="/husky_experience_message?article=first-impressions-matter">First Impressions Matter</a></span></h4>
        <p><span class="myuw-highlight">How you present yourself in an email message can make (or break) your connection with another person. Being thoughtful and respectful can go a long way. <a class="myuw-link-card-teaser" href="/husky_experience_message?article=first-impressions-matter">Read more</a></span></p>
    </div>
</div>
